<?php

/* Reminder: always indent with 4 spaces (no tabs). */
// +---------------------------------------------------------------------------+
// | Facebook Like Plugin 1.0.0                                                |
// +---------------------------------------------------------------------------+
// | functions.inc                                                             |
// |                                                                           |
// | This file does two things: 1) it implements the necessary Geeklog Plugin  |
// | API methods and 2) implements all the common code needed by this plugin.  |
// +---------------------------------------------------------------------------+
// | Copyright (C) 2011 by the following authors:                              |
// |                                                                           |
// | Authors: Rouslan Placella - rouslan AT placella DOT com                   |
// +---------------------------------------------------------------------------+
// | Created with the Geeklog Plugin Toolkit.                                  |
// +---------------------------------------------------------------------------+
// |                                                                           |
// | This program is free software; you can redistribute it and/or             |
// | modify it under the terms of the GNU General Public License               |
// | as published by the Free Software Foundation; either version 2            |
// | of the License, or (at your option) any later version.                    |
// |                                                                           |
// | This program is distributed in the hope that it will be useful,           |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
// | GNU General Public License for more details.                              |
// |                                                                           |
// | You should have received a copy of the GNU General Public License         |
// | along with this program; if not, write to the Free Software Foundation,   |
// | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           |
// |                                                                           |
// +---------------------------------------------------------------------------+

/**
* @package FacebookLike
*/

if (strpos(strtolower($_SERVER['PHP_SELF']), 'functions.inc') !== false) {
    die ('This file can not be used on its own.');
}

/**
 * Language file include
 */
$plugin_path = $_CONF['path'] . 'plugins/fblike/';
$langfile = $plugin_path . 'language/' . $_CONF['language'] . '.php';

if (file_exists($langfile)) {
    require_once $langfile;
} else {
    require_once $plugin_path . 'language/english.php';
}

/**
* Check and see if we need to load the plugin configuration
*/ 
if (!isset($_FB_CONF)) {
    require_once $_CONF['path_system'] . 'classes/config.class.php';
    
    $fb_config = config::get_instance();
    $_FB_CONF = $fb_config->get_config('fblike');
}

// +---------------------------------------------------------------------------+
// | Geeklog Plugin API Implementation                                         |
// +---------------------------------------------------------------------------+

/**
* Implements a [fblike:] autotag.
*
* @param    string  $op         operation to perform
* @param    string  $content    item (e.g. story text), including the autotag
* @param    array   $autotag    parameters used in the autotag
* @param    mixed               tag names (for $op='tagname') or formatted content
*
*/

function plugin_autotags_fblike($op, $content = '', $autotag = '')
{
    global $_CONF, $LANG_FBLIKE_1, $_FB_CONF;

    // [fblike: layout show_faces action colorscheme font width height]
    if ($op == 'tagname') {
        return 'fblike';
    } elseif ($op == 'parse') {
        if (isset($autotag['parm1']) && !empty($autotag['parm1'])) {
            $url = PLG_getItemInfo('article', $autotag['parm1'], 'url');
            if (!empty($url)) {
                $width  = 90;
                $height = 20;
                if ($_FB_CONF['layout'] == 'standard') {
                    $width = 450;
                    $height = 35;
                } else if ($_FB_CONF['layout'] == 'button_count') {
                    $width = 90;
                    $height = 20;
                } else if ($_FB_CONF['layout'] == 'box_count') {
                    $width = 55;
                    $height = 65;
                }

                if ($_FB_CONF['faces']) {
                    $height = 80;
                }

                $html = '<iframe src="http://www.facebook.com/plugins/like.php?href=' . urlencode($url) . '&amp;'
                      . 'layout='      . $_FB_CONF['layout'] . '&amp;'
                      . 'show_faces='  . $_FB_CONF['faces'] . '&amp;'
                      . 'width='       . $width . '&amp;'
                      . 'action='      . $_FB_CONF['action']. '&amp;'
                      . 'colorscheme=' . $_FB_CONF['colours'] . '&amp;'
                      . 'height='      . $height . '&amp;'
                      . 'font='        . urlencode($_FB_CONF['font']) . '&amp;'
                      . 'locale='      . $_CONF['locale'] . '" scrolling="no" frameborder="0" style="border: none; overflow:hidden;'
                      . 'width:'       . $width . 'px; '
                      . 'height:'      . $height . 'px;" allowTransparency="true"></iframe>';

                $content = str_replace($autotag['tagstr'], $html, $content);
            }
        }
        return $content;
    }
}

/**
* Return plugin entry for "Command and Control" (moderation.php)
*
* @return  array  Array containing (plugin name, admin url, url of plugin icon)
*
*/
function plugin_cclabel_fblike()
{
    global $_CONF, $LANG_FBLIKE_1;

    $retval = array($LANG_FBLIKE_1['plugin_name'],
        $_CONF['site_admin_url'] . '/plugins/fblike/index.php',
        plugin_geticon_fblike());

    return $retval;
}

/**
* Return plugin entry for the Admins Only block
*
* @return array Array containing (plugin name, plugin admin url, # of plugin items or '')
*/
function plugin_getadminoption_fblike()
{
    global $_CONF, $LANG_FBLIKE_1;

    return array($LANG_FBLIKE_1['plugin_name'],
        $_CONF['site_admin_url'] . '/plugins/fblike/index.php', '');
}

/**
* Returns the URL of the plugin's icon
*
* @return   string      URL of the icon
*
*/
function plugin_geticon_fblike()
{
    global $_CONF;

    // popular alternative location:
    // return $_CONF['site_url'] . '/fblike/images/fblike.png';

    return $_CONF['site_admin_url'] . '/plugins/fblike/images/fblike.png';
}

/**
 * Returns the current plugin code version
 *
 * @return string    plugin version
 */
function plugin_chkVersion_fblike()
{
    global $_CONF;

    require_once $_CONF['path'] . 'plugins/fblike/autoinstall.php';

    $inst_parms = plugin_autoinstall_fblike('fblike');

    return $inst_parms['info']['pi_version'];
}

/**
* Update the plugin
*
* @return   int     Number of message to display or true for success
*
*/
function plugin_upgrade_fblike()
{
    global $_CONF, $_TABLES;

    $installed_version = DB_getItem($_TABLES['plugins'], 'pi_version',
                                    "pi_name = 'fblike'");
    $code_version = plugin_chkVersion_fblike();
    if ($installed_version == $code_version) {
        // nothing to do
        return true;
    }

    require_once $_CONF['path'] . 'plugins/fblike/autoinstall.php';

    if (! plugin_compatible_with_this_version_fblike('fblike')) {
        return 3002;
    }

    // other update code goes here

    // update plugin version number
    $inst_parms = plugin_autoinstall_fblike('fblike');
    $pi_gl_version = $inst_parms['info']['pi_gl_version'];

    DB_query("UPDATE {$_TABLES['plugins']} SET pi_version = '$code_version', pi_gl_version = '$pi_gl_version' WHERE pi_name = 'fblike'");

    return true;
}

/**
* Automatic uninstall function for plugins
*
* This code is automatically uninstalling the plugin.
* It passes an array to the core code function that removes
* tables, groups, features and php blocks from the tables.
* Additionally, this code can perform special actions that cannot be
* foreseen by the core code (interactions with other plugins for example)
*
* @return   array   Plugin information
*
*/
function plugin_autouninstall_fblike()
{
    $out = array (
        /* give the name of the tables, without $_TABLES[] */
        'tables' => array(/* e.g. 'fblike' */),
        /* give the full name of the group, as in the db */
        'groups' => array('Facebook Like Admin'),
        /* give the full name of the feature, as in the db */
        'features' => array('fblike.admin'),
        /* give the full name of the block, including 'phpblock_', etc */
        'php_blocks' => array(),
        /* give all vars with their name */
        'vars' => array()
    );

    return $out;
}

?>
